;+
;
; =============================
; dew_temp_airt_rel_humidity_jv
; =============================
;
; .. function:: dew_temp_airt_rel_humidity_jv(t, td)
;
;     :param t: air temperature in degC
;     :param td: dew point temperature in degC
;
;
; SEE ALSO
; ========
;
; EXAMPLES
; ========
;
; ::
;
;    IDL> t=+todo+
;    IDL> td=+todo+
;    IDL> result=dew_temp_airt_rel_humidity_jv(t, td)
;
;
; TODO
; ====
;
; hard coded directory - usage of ${PROJECT_ID}
;
; coding rules
;
; EVOLUTIONS
; ==========
;
; - fplod 20101214T093615Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * minimal header
;
; - pbk 2008
;
;   * creation
;
;-
function dew_temp_airt_rel_humidity_jv, t,td

if (not keyword_set(t)) then t=28            ; air temperature in degC
if (not keyword_set(td)) then td=23           ; dew point temperature in degC
es0=6.11        ; reference saturation vapor pressure (hPa)

;; calculating fields.  First saturation vapor pressure (Es) and
;; actual vapor pressure are calculated.  The ratio (E/Es)*100
;; gives the relative humidity

e=es0*10^(7.5*td/(237.7+td))
es=es0*10^(7.5*t/(237.7+T))

rh=(e/es)*100
;;;print, 'RH = ',rh

return, rh

end
